<?php
namespace Mcselementor\Widgets;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}
/**
 *
 * Laamya elementor about page section widget.
 *
 * @since 1.0
 */
class Mcs_Buttons extends Widget_Base {

	public function get_name() {
		return 'mcs-buttons';
	}

	public function get_title() {
		return esc_html__( 'Messenger chat support buttons', 'ta-mcs' );
	}

	public function get_icon() {
		return 'eicon-headphones';
	}

	public function get_categories() {
		return [ 'mcs-elements' ];
	}

	protected function _register_controls() {

      
        // ----------------------------------------  Click to dial Buttons Settings ------------------------------

        $this->start_controls_section(
			'mcs__general__settings',
			[
				'label' => esc_html__( 'General settings', 'ta-mcs' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
        
        $this->add_control(
            'fbid', [
                'label'     => esc_html__( 'Facebook ID', 'ta-mcs' ),
                'description' => esc_html__('Add your facebook ID eg: ThemeAtelier', 'ta-mcs'),
                'label_block' => false,
                'type'      => Controls_Manager::TEXT,
            ]
        );

        $this->add_control(
            'style', [
                'label' => esc_html__( 'Style', 'ta-mcs' ),
                'type'  => Controls_Manager::SELECT,
                'label_block' => false,
                'default' => '1',
                'options' => array(
                    '1'  => esc_html__( 'Advanced button', 'ta-mcs' ),
                    '2'  => esc_html__( 'Basic button', 'ta-mcs' ),
                )

            ]
        );

        $this-> add_control(
            'agent__photo', [
                'label' => esc_html__( 'Agent photo', 'ta-mcs' ),
                'description' => esc_html__('Add agent photo to show in button.', 'ta-mcs'),
                'type'  => Controls_Manager::MEDIA,
                'label_block' => true,
                'default' => [
                    'url' => MCS_DIR_URL . 'assets/image/user.webp',
                ],
                'condition' => [
                    'style' => '1',
                ],
            ]
        );
        
        $this-> add_control(
            'agent__name', [
                'label' => esc_html__( 'Agent name', 'ta-mcs' ),
                'description' => esc_html__('Write agent name to show in button.', 'ta-mcs'),
                'type'  => Controls_Manager::TEXT,
                'label_block' => false,
                'default' => esc_html__('Robert', 'ta-mcs'),
                'condition' => [
                    'style' => '1',
                ],
            ]
        );

        $this-> add_control(
            'agent__designation', [
                'label' => esc_html__( 'Agent designation', 'ta-mcs' ),
                'description' => esc_html__('Write agent designation to show in button.', 'ta-mcs'),
                'type'  => Controls_Manager::TEXT,
                'label_block' => false,
                'default' => esc_html__('Sales Support', 'ta-mcs'),
                'condition' => [
                    'style' => '1',
                ],
            ]
        );

        $this-> add_control(
            'custom__button__label', [
                'label' => esc_html__( 'Button label', 'ta-mcs' ),
                'description' => esc_html__('Add custom button label.', 'ta-mcs'),
                'type'  => Controls_Manager::TEXT,
                'label_block' => true,
                'default' => esc_html__('How can I help you?', 'ta-mcs'),
            ]
        );

        $this-> add_control(
            'online__text', [
                'label' => esc_html__( 'Online badget text', 'ta-mcs' ),
                'description' => esc_html__('Add custom badget text when user in online.', 'ta-mcs'),
                'type'  => Controls_Manager::TEXT,
                'label_block' => false,
                'default' => esc_html__('I\'m avaiable', 'ta-mcs'),
                'condition' => [
                    'style' => '1',
                ],
            ]
        );

        $this-> add_control(
            'offline__text', [
                'label' => esc_html__( 'Offline badget text', 'ta-mcs' ),
                'description' => esc_html__('Add custom badget text when user in offline.', 'ta-mcs'),
                'type'  => Controls_Manager::TEXT,
                'label_block' => false,
                'default' => esc_html__('I\'m offline', 'ta-mcs'),
                'condition' => [
                    'style' => '1',
                ],
            ]
        );

        $this->end_controls_section(); // End section top content


        $this->start_controls_section(
			'mcs__availablity__manager',
			[
				'label' => esc_html__( 'Chat settings', 'ta-mcs' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
                'condition' => [
                    'style' => '1',
                ],
			]
		);



        $this-> add_control(
            'timezone', [
                'label' => esc_html__( 'Timezone', 'ta-mcs' ),
                'description' => esc_html__('When using the date and time from the user browser you can transform it to your current timezone (in case your user is in a different timezone)', 'ta-mcs'),
                'type'  => Controls_Manager::SELECT2,
                'label_block' => true,
                'multiple' => false,
                'default' => '1',
                'options' => array(
                    '1' => esc_html__( 'Select timezone', 'ta-mcs' ),
                    'Africa/Abidjan' => esc_html__( 'Africa/Abidjan', 'ta-mcs' ),
                    'Africa/Accra' => esc_html__( 'Africa/Accra', 'ta-mcs' ),
                    'Africa/Addis_Ababa' => esc_html__( 'Africa/Addis_Ababa', 'ta-mcs' ),
                    'Africa/Algiers' => esc_html__( 'Africa/Algiers', 'ta-mcs' ),
                    'Africa/Asmara' => esc_html__( 'Africa/Asmara', 'ta-mcs' ),
                    'Africa/Asmera' => esc_html__( 'Africa/Asmera', 'ta-mcs' ),
                    'Africa/Bamako' => esc_html__( 'Africa/Bamako', 'ta-mcs' ),
                    'Africa/Bangui' => esc_html__( 'Africa/Bangui', 'ta-mcs' ),
                    'Africa/Banjul' => esc_html__( 'Africa/Banjul', 'ta-mcs' ),
                    'Africa/Bissau' => esc_html__( 'Africa/Bissau', 'ta-mcs' ),
                    'Africa/Blantyre' => esc_html__( 'Africa/Blantyre', 'ta-mcs' ),
                    'Africa/Brazzaville' => esc_html__( 'Africa/Brazzaville', 'ta-mcs' ),
                    'Africa/Bujumbura' => esc_html__( 'Africa/Bujumbura', 'ta-mcs' ),
                    'Africa/Cairo' => esc_html__( 'Africa/Cairo', 'ta-mcs' ),
                    'Africa/Casablanca' => esc_html__( 'Africa/Casablanca', 'ta-mcs' ),
                    'Africa/Ceuta' => esc_html__( 'Africa/Ceuta', 'ta-mcs' ),
                    'Africa/Conakry' => esc_html__( 'Africa/Conakry', 'ta-mcs' ),
                    'Africa/Dakar' => esc_html__( 'Africa/Dakar', 'ta-mcs' ),
                    'Africa/Dar_es_Salaam' => esc_html__( 'Africa/Dar_es_Salaam', 'ta-mcs' ),
                    'Africa/Djibouti' => esc_html__( 'Africa/Djibouti', 'ta-mcs' ),
                    'Africa/Douala' => esc_html__( 'Africa/Douala', 'ta-mcs' ),
                    'Africa/El_Aaiun' => esc_html__( 'Africa/El_Aaiun', 'ta-mcs' ),
                    'Africa/Freetown' => esc_html__( 'Africa/Freetown', 'ta-mcs' ),
                    'Africa/Gaborone' => esc_html__( 'Africa/Gaborone', 'ta-mcs' ),
                    'Africa/Harare' => esc_html__( 'Africa/Harare', 'ta-mcs' ),
                    'Africa/Johannesburg' => esc_html__( 'Africa/Johannesburg', 'ta-mcs' ),
                    'Africa/Juba' => esc_html__( 'Africa/Juba', 'ta-mcs' ),
                    'Africa/Kampala' => esc_html__( 'Africa/Kampala', 'ta-mcs' ),
                    'Africa/Khartoum' => esc_html__( 'Africa/Khartoum', 'ta-mcs' ),
                    'Africa/Kigali' => esc_html__( 'Africa/Kigali', 'ta-mcs' ),
                    'Africa/Kinshasa' => esc_html__( 'Africa/Kinshasa', 'ta-mcs' ),
                    'Africa/Lagos' => esc_html__( 'Africa/Lagos', 'ta-mcs' ),
                    'Africa/Libreville' => esc_html__( 'Africa/Libreville', 'ta-mcs' ),
                    'Africa/Lome' => esc_html__( 'Africa/Lome', 'ta-mcs' ),
                    'Africa/Luanda' => esc_html__( 'Africa/Luanda', 'ta-mcs' ),
                    'Africa/Lubumbashi' => esc_html__( 'Africa/Lubumbashi', 'ta-mcs' ),
                    'Africa/Lusaka' => esc_html__( 'Africa/Lusaka', 'ta-mcs' ),
                    'Africa/Malabo' => esc_html__( 'Africa/Malabo', 'ta-mcs' ),
                    'Africa/Maputo' => esc_html__( 'Africa/Maputo', 'ta-mcs' ),
                    'Africa/Maseru' => esc_html__( 'Africa/Maseru', 'ta-mcs' ),
                    'Africa/Mbabane' => esc_html__( 'Africa/Mbabane', 'ta-mcs' ),
                    'Africa/Mogadishu' => esc_html__( 'Africa/Mogadishu', 'ta-mcs' ),
                    'Africa/Monrovia' => esc_html__( 'Africa/Monrovia', 'ta-mcs' ),
                    'Africa/Nairobi' => esc_html__( 'Africa/Nairobi', 'ta-mcs' ),
                    'Africa/Ndjamena' => esc_html__( 'Africa/Ndjamena', 'ta-mcs' ),
                    'Africa/Niamey' => esc_html__( 'Africa/Niamey', 'ta-mcs' ),
                    'Africa/Nouakchott' => esc_html__( 'Africa/Nouakchott', 'ta-mcs' ),
                    'Africa/Ouagadougou' => esc_html__( 'Africa/Ouagadougou', 'ta-mcs' ),
                    'Africa/Porto-Novo' => esc_html__( 'Africa/Porto-Novo', 'ta-mcs' ),
                    'Africa/Sao_Tome' => esc_html__( 'Africa/Sao_Tome', 'ta-mcs' ),
                    'Africa/Timbuktu' => esc_html__( 'Africa/Timbuktu', 'ta-mcs' ),
                    'Africa/Tripoli' => esc_html__( 'Africa/Tripoli', 'ta-mcs' ),
                    'Africa/Tunis' => esc_html__( 'Africa/Tunis', 'ta-mcs' ),
                    'Africa/Windhoek' => esc_html__( 'Africa/Windhoek', 'ta-mcs' ),
                    'America/Adak' => esc_html__( 'America/Adak', 'ta-mcs' ),
                    'America/Anchorage' => esc_html__( 'America/Anchorage', 'ta-mcs' ),
                    'America/Anguilla' => esc_html__( 'America/Anguilla', 'ta-mcs' ),
                    'America/Antigua' => esc_html__( 'America/Antigua', 'ta-mcs' ),
                    'America/Araguaina' => esc_html__( 'America/Araguaina', 'ta-mcs' ),
                    'America/Argentina/Buenos_Aires' => esc_html__( 'America/Argentina/Buenos_Aires', 'ta-mcs' ),
                    'America/Argentina/Catamarca' => esc_html__( 'America/Argentina/Catamarca', 'ta-mcs' ),
                    'America/Argentina/ComodRivadavia' => esc_html__( 'America/Argentina/ComodRivadavia', 'ta-mcs' ),
                    'America/Argentina/Cordoba' => esc_html__( 'America/Argentina/Cordoba', 'ta-mcs' ),
                    'America/Argentina/Jujuy' => esc_html__( 'America/Argentina/Jujuy', 'ta-mcs' ),
                    'America/Argentina/La_Rioja' => esc_html__( 'America/Argentina/La_Rioja', 'ta-mcs' ),
                    'America/Argentina/Mendoza' => esc_html__( 'America/Argentina/Mendoza', 'ta-mcs' ),
                    'America/Argentina/Rio_Gallegos' =>esc_html__( 'America/Argentina/Rio_Gallegos', 'ta-mcs' ),
                    'America/Argentina/Salta' => esc_html__( 'America/Argentina/Salta', 'ta-mcs' ),
                    'America/Argentina/San_Juan' => esc_html__( 'America/Argentina/San_Juan', 'ta-mcs' ),
                    'America/Argentina/San_Luis' => esc_html__( 'America/Argentina/San_Luis', 'ta-mcs' ),
                    'America/Argentina/Tucuman' => esc_html__( 'America/Argentina/Tucuman', 'ta-mcs' ),
                    'America/Argentina/Ushuaia' => esc_html__( 'America/Argentina/Ushuaia', 'ta-mcs' ),
                    'America/Aruba' => esc_html__( 'America/Aruba', 'ta-mcs' ),
                    'America/Asuncion' => esc_html__( 'America/Asuncion', 'ta-mcs' ),
                    'America/Atikokan' => esc_html__( 'America/Atikokan', 'ta-mcs' ),
                    'America/Atka' => esc_html__( 'America/Atka', 'ta-mcs' ),
                    'America/Bahia' => esc_html__( 'America/Bahia', 'ta-mcs' ),
                    'America/Bahia_Banderas' => esc_html__( 'America/Bahia_Banderas', 'ta-mcs' ),
                    'America/Barbados' => esc_html__( 'America/Barbados', 'ta-mcs' ),
                    'America/Belem' => esc_html__( 'America/Belem', 'ta-mcs' ),
                    'America/Belize' => esc_html__( 'America/Belize', 'ta-mcs' ),
                    'America/Blanc-Sablon' => esc_html__( 'America/Blanc-Sablon', 'ta-mcs' ),
                    'America/Boa_Vista' => esc_html__( 'America/Boa_Vista', 'ta-mcs' ),
                    'America/Bogota' => esc_html__( 'America/Bogota', 'ta-mcs' ),
                    'America/Boise' => esc_html__( 'America/Boise', 'ta-mcs' ),
                    'America/Buenos_Aires' => esc_html__( 'America/Buenos_Aires', 'ta-mcs' ),
                    'America/Cambridge_Bay' => esc_html__( 'America/Cambridge_Bay', 'ta-mcs' ),
                    'America/Campo_Grande' => esc_html__( 'America/Campo_Grande', 'ta-mcs' ),
                    'America/Cancun' => esc_html__( 'America/Cancun', 'ta-mcs' ),
                    'America/Caracas' => esc_html__( 'America/Caracas', 'ta-mcs' ),
                    'America/Catamarca' => esc_html__( 'America/Catamarca', 'ta-mcs' ),
                    'America/Cayenne' => esc_html__( 'America/Cayenne', 'ta-mcs' ),
                    'America/Cayman' => esc_html__( 'America/Cayman', 'ta-mcs' ),
                    'America/Chicago' => esc_html__( 'America/Chicago', 'ta-mcs' ),
                    'America/Chihuahua' => esc_html__( 'America/Chihuahua', 'ta-mcs' ),
                    'America/Coral_Harbour' => esc_html__( 'America/Coral_Harbour', 'ta-mcs' ),
                    'America/Cordoba' => esc_html__( 'America/Cordoba', 'ta-mcs' ),
                    'America/Costa_Rica' => esc_html__( 'America/Costa_Rica', 'ta-mcs' ),
                    'America/Creston' => esc_html__( 'America/Creston', 'ta-mcs' ),
                    'America/Cuiaba' => esc_html__( 'America/Cuiaba', 'ta-mcs' ),
                    'America/Curacao' => esc_html__( 'America/Curacao', 'ta-mcs' ),
                    'America/Danmarkshavn' => esc_html__( 'America/Danmarkshavn', 'ta-mcs' ),
                    'America/Dawson' => esc_html__( 'America/Dawson', 'ta-mcs' ),
                    'America/Araguaina' => esc_html__( 'America/Araguaina', 'ta-mcs' ),
                    'America/Denver' => esc_html__( 'America/Denver', 'ta-mcs' ),
                    'America/Araguaina' => esc_html__( 'America/Araguaina', 'ta-mcs' ),
                    'America/Dominica' => esc_html__( 'America/Dominica', 'ta-mcs' ),
                    'America/Edmonton' => esc_html__( 'America/Edmonton', 'ta-mcs' ),
                    'America/Eirunepe' => esc_html__( 'America/Eirunepe', 'ta-mcs' ),
                    'America/El_Salvador' => esc_html__( 'America/El_Salvador', 'ta-mcs' ),
                    'America/Ensenada' => esc_html__( 'America/Ensenada', 'ta-mcs' ),
                    'America/Fort_Nelson' => esc_html__( 'America/Fort_Nelson', 'ta-mcs' ),
                    'America/Fort_Wayne' => esc_html__( 'America/Fort_Wayne', 'ta-mcs' ),
                    'America/Fortaleza' => esc_html__( 'America/Fortaleza', 'ta-mcs' ),
                    'America/Glace_Bay' => esc_html__( 'America/Glace_Bay', 'ta-mcs' ),
                    'America/Godthab' => esc_html__( 'America/Godthab', 'ta-mcs' ),
                    'America/Goose_Bay' => esc_html__( 'America/Goose_Bay', 'ta-mcs' ),
                    'America/Grand_Turk' => esc_html__( 'America/Grand_Turk', 'ta-mcs' ),
                    'America/Grenada' => esc_html__( 'America/Grenada', 'ta-mcs' ),
                    'America/Guadeloupe' => esc_html__( 'America/Guadeloupe', 'ta-mcs' ),
                    'America/Guatemala' => esc_html__( 'America/Guatemala', 'ta-mcs' ),
                    'America/Guayaquil' => esc_html__( 'America/Guayaquil', 'ta-mcs' ),
                    'America/Guyana' => esc_html__( 'America/Guyana', 'ta-mcs' ),
                    'America/Halifax' => esc_html__( 'America/Halifax', 'ta-mcs' ),
                    'America/Havana' => esc_html__( 'America/Havana', 'ta-mcs' ),
                    'America/Hermosillo' =>esc_html__( 'America/Hermosillo', 'ta-mcs' ),
                    'America/Indiana/Indianapolis' => esc_html__( 'Indiana/Indianapolis', 'ta-mcs' ),
                    'America/Indiana/Knox' => esc_html__( 'America/Indiana/Knox', 'ta-mcs' ),
                    'America/Indiana/Marengo' => esc_html__( 'America/Indiana/Marengo', 'ta-mcs' ),
                    'America/Indiana/Petersburg' => esc_html__( 'America/Indiana/Petersburg', 'ta-mcs' ),
                    'America/Indiana/Tell_City' => esc_html__( 'America/Indiana/Tell_City', 'ta-mcs' ),
                    'America/Indiana/Vevay' => esc_html__( 'America/Indiana/Vevay', 'ta-mcs' ),
                    'America/Indiana/Vincennes' => esc_html__( 'America/Indiana/Vincennes', 'ta-mcs' ),
                    'America/Indiana/Winamac' => esc_html__( 'America/Indiana/Winamac', 'ta-mcs' ),
                    'America/Indianapolis' => esc_html__( 'America/Indianapolis', 'ta-mcs' ),
                    'America/Inuvik' => esc_html__( 'America/Inuvik', 'ta-mcs' ),
                    'America/Iqaluit' => esc_html__( 'America/Iqaluit', 'ta-mcs' ),
                    'America/Jamaica' => esc_html__( 'America/Jamaica', 'ta-mcs' ),
                    'America/Jujuy' => esc_html__( 'America/Jujuy', 'ta-mcs' ),
                    'America/Juneau' => esc_html__( 'America/Juneau', 'ta-mcs' ),
                    'America/Kentucky/Louisville' => esc_html__( 'America/Kentucky/Louisville', 'ta-mcs' ),
                    'America/Kentucky/Monticello' => esc_html__( 'America/Kentucky/Monticello', 'ta-mcs' ),
                    'America/Knox_IN' => esc_html__( 'America/Knox_IN', 'ta-mcs' ),
                    'America/Kralendijk' => esc_html__( 'America/Kralendijk', 'ta-mcs' ),
                    'America/La_Paz' => esc_html__( 'America/La_Paz', 'ta-mcs' ),
                    'America/Lima' => esc_html__( 'America/Lima', 'ta-mcs' ),
                    'America/Los_Angeles' => esc_html__( 'America/Los_Angeles', 'ta-mcs' ),
                    'America/Louisville' => esc_html__( 'America/Louisville', 'ta-mcs' ),
                    'America/Lower_Princes' => esc_html__( 'America/Lower_Princes', 'ta-mcs' ),
                    'America/Maceio' => esc_html__( 'America/Maceio', 'ta-mcs' ),
                    'America/Managua' => esc_html__( 'America/Managua', 'ta-mcs' ),
                    'America/Manaus' => esc_html__( 'America/Manaus', 'ta-mcs' ),
                    'America/Marigot' => esc_html__( 'America/Marigot', 'ta-mcs' ),
                    'America/Martinique' => esc_html__( 'America/Martinique', 'ta-mcs' ),
                    'America/Matamoros' => esc_html__( 'America/Matamoros', 'ta-mcs' ),
                    'America/Mazatlan' => esc_html__( 'America/Mazatlan', 'ta-mcs' ),
                    'America/Mendoza' => esc_html__( 'America/Mendoza', 'ta-mcs' ),
                    'America/Menominee' => esc_html__( 'America/Menominee', 'ta-mcs' ),
                    'America/Merida' => esc_html__( 'America/Merida', 'ta-mcs' ),
                    'America/Metlakatla' => esc_html__( 'America/Metlakatla', 'ta-mcs' ),
                    'America/Mexico_City' => esc_html__( 'America/Mexico_City', 'ta-mcs' ),
                    'America/Miquelon' => esc_html__( 'America/Miquelon', 'ta-mcs' ),
                    'America/Moncton' => esc_html__( 'America/Moncton', 'ta-mcs' ),
                    'America/Monterrey' => esc_html__( 'America/Monterrey', 'ta-mcs' ),
                    'America/Montevideo' => esc_html__( 'America/Montevideo', 'ta-mcs' ),
                    'America/Montreal' => esc_html__( 'America/Montreal', 'ta-mcs' ),
                    'America/Montserrat' => esc_html__( 'America/Montserrat', 'ta-mcs' ),
                    'America/Nassau' => esc_html__( 'America/Nassau', 'ta-mcs' ),
                    'America/New_York' => esc_html__( 'America/New_York', 'ta-mcs' ),
                    'America/Nipigon' => esc_html__( 'America/Nipigon', 'ta-mcs' ),
                    'America/Nome' => esc_html__( 'America/Nome', 'ta-mcs' ),
                    'America/Noronha' => esc_html__( 'America/Noronha', 'ta-mcs' ),
                    'America/North_Dakota/Beulah' => esc_html__( 'America/North_Dakota/Beulah', 'ta-mcs' ),
                    'America/North_Dakota/Center' => esc_html__( 'America/North_Dakota/Center', 'ta-mcs' ),
                    'America/North_Dakota/New_Salem' => esc_html__( 'America/North_Dakota/New_Salem', 'ta-mcs' ),
                    'America/Ojinaga' => esc_html__( 'America/Ojinaga', 'ta-mcs' ),
                    'America/Panama' => esc_html__( 'America/Panama', 'ta-mcs' ),
                    'America/Pangnirtung' => esc_html__( 'America/Pangnirtung', 'ta-mcs' ),
                    'America/Paramaribo' => esc_html__( 'America/Paramaribo', 'ta-mcs' ),
                    'America/Phoenix' => esc_html__( 'America/Phoenix', 'ta-mcs' ),
                    'America/Port-au-Prince' => esc_html__( 'America/Port-au-Prince', 'ta-mcs' ),
                    'America/Port_of_Spain' => esc_html__( 'America/Port_of_Spain', 'ta-mcs' ),
                    'America/Porto_Acre' => esc_html__( 'America/Porto_Acre', 'ta-mcs' ),
                    'America/Porto_Velho' => esc_html__( 'America/Porto_Velho', 'ta-mcs' ),
                    'America/Puerto_Rico' => esc_html__( 'America/Puerto_Rico', 'ta-mcs' ),
                    'America/Punta_Arenas' => esc_html__( 'America/Punta_Arenas', 'ta-mcs' ),
                    'America/Rainy_River' => esc_html__( 'America/Rainy_River', 'ta-mcs' ),
                    'America/Rankin_Inlet' => esc_html__( 'America/Rankin_Inlet', 'ta-mcs' ),
                    'America/Recife' => esc_html__( 'America/Recife', 'ta-mcs' ),
                    'America/Regina' => esc_html__( 'America/Regina', 'ta-mcs' ),
                    'America/Resolute' => esc_html__( 'America/Resolute', 'ta-mcs' ),
                    'America/Rio_Branco' => esc_html__( 'America/Rio_Branco', 'ta-mcs' ),
                    'America/Rosario' => esc_html__( 'America/Rosario', 'ta-mcs' ),
                    'America/Santa_Isabel' => esc_html__( 'America/Santa_Isabel', 'ta-mcs' ),
                    'America/Santarem' => esc_html__( 'America/Santarem', 'ta-mcs' ),
                    'America/Santiago' => esc_html__( 'America/Santiago', 'ta-mcs' ),
                    'America/Santo_Domingo' => esc_html__( 'America/Santo_Domingo', 'ta-mcs' ),
                    'America/Sao_Paulo' => esc_html__( 'America/Sao_Paulo', 'ta-mcs' ),
                    'America/Scoresbysund' => esc_html__( 'America/Scoresbysund', 'ta-mcs' ),
                    'America/Shiprock' => esc_html__( 'America/Shiprock', 'ta-mcs' ),
                    'America/Sitka' => esc_html__( 'America/Sitka', 'ta-mcs' ),
                    'America/St_Barthelemy' => esc_html__( 'America/St_Barthelemy', 'ta-mcs' ),
                    'America/St_Johns' => esc_html__( 'America/St_Johns', 'ta-mcs' ),
                    'America/St_Kitts' => esc_html__( 'America/St_Kitts', 'ta-mcs' ),
                    'America/St_Lucia' => esc_html__( 'America/St_Lucia', 'ta-mcs' ),
                    'America/St_Thomas' => esc_html__( 'America/St_Thomas', 'ta-mcs' ),
                    'America/St_Vincent' => esc_html__( 'America/St_Vincent', 'ta-mcs' ),
                    'America/Swift_Current' => esc_html__( 'America/Swift_Current', 'ta-mcs' ),
                    'America/Tegucigalpa' => esc_html__( 'America/Tegucigalpa', 'ta-mcs' ),
                    'America/Thule' => esc_html__( 'America/Thule', 'ta-mcs' ),
                    'America/Thunder_Bay' => esc_html__( 'America/Thunder_Bay', 'ta-mcs' ),
                    'America/Tijuana' => esc_html__( 'America/Tijuana', 'ta-mcs' ),
                    'America/Toronto' => esc_html__( 'America/Toronto', 'ta-mcs' ),
                    'America/Tortola' => esc_html__( 'America/Tortola', 'ta-mcs' ),
                    'America/Vancouver' => esc_html__( 'America/Vancouver', 'ta-mcs' ),
                    'America/Virgin' => esc_html__( 'America/Virgin', 'ta-mcs' ),
                    'America/Whitehorse' => esc_html__( 'America/Whitehorse', 'ta-mcs' ),
                    'America/Winnipeg' => esc_html__( 'America/Winnipeg', 'ta-mcs' ),
                    'America/Yakutat' => esc_html__( 'America/Yakutat', 'ta-mcs' ),
                    'America/Yellowknife' => esc_html__( 'America/Yellowknife', 'ta-mcs' ),
                    'Antarctica/Casey' => esc_html__( 'Antarctica/Casey', 'ta-mcs' ),
                    'Antarctica/Davis' => esc_html__( 'Antarctica/Davis', 'ta-mcs' ),
                    'Antarctica/DumontDUrville' => esc_html__( 'Antarctica/DumontDUrville', 'ta-mcs' ),
                    'Antarctica/Macquarie' => esc_html__( 'Antarctica/Macquarie', 'ta-mcs' ),
                    'Antarctica/Mawson' => esc_html__( 'Antarctica/Mawson', 'ta-mcs' ),
                    'Antarctica/McMurdo' => esc_html__( 'Antarctica/McMurdo', 'ta-mcs' ),
                    'Antarctica/Palmer' => esc_html__( 'Antarctica/Palmer', 'ta-mcs' ),
                    'Antarctica/Rothera' => esc_html__( 'Antarctica/Rothera', 'ta-mcs' ),
                    'Antarctica/South_Pole' => esc_html__( 'Antarctica/South_Pole', 'ta-mcs' ),
                    'Antarctica/Syowa' => esc_html__( 'Antarctica/Syowa', 'ta-mcs' ),
                    'Antarctica/Troll' => esc_html__( 'Antarctica/Troll', 'ta-mcs' ),
                    'Antarctica/Vostok' => esc_html__( 'Antarctica/Vostok', 'ta-mcs' ),
                    'Arctic/Longyearbyen' => esc_html__( 'Arctic/Longyearbyen', 'ta-mcs' ),
                    'Asia/Aden' => esc_html__( 'Asia/Aden', 'ta-mcs' ),
                    'Asia/Almaty' => esc_html__( 'Asia/Almaty', 'ta-mcs' ),
                    'Asia/Amman' => esc_html__( 'Asia/Amman', 'ta-mcs' ),
                    'Asia/Anadyr' => esc_html__( 'Asia/Anadyr', 'ta-mcs' ),
                    'Asia/Aqtau' => esc_html__( 'Asia/Aqtau', 'ta-mcs' ),
                    'Asia/Aqtobe' => esc_html__( 'Asia/Aqtobe', 'ta-mcs' ),
                    'Asia/Ashgabat' => esc_html__( 'Asia/Ashgabat', 'ta-mcs' ),
                    'Asia/Ashkhabad' => esc_html__( 'Asia/Ashkhabad', 'ta-mcs' ),
                    'Asia/Atyrau' => esc_html__( 'Asia/Atyrau', 'ta-mcs' ),
                    'Asia/Baghdad' => esc_html__( 'Asia/Baghdad', 'ta-mcs' ),
                    'Asia/Bahrain' => esc_html__( 'Asia/Bahrain', 'ta-mcs' ),
                    'Asia/Baku' => esc_html__( 'Asia/Baku', 'ta-mcs' ),
                    'Asia/Bangkok' => esc_html__( 'Asia/Bangkok', 'ta-mcs' ),
                    'Asia/Barnaul' => esc_html__( 'Asia/Barnaul', 'ta-mcs' ),
                    'Asia/Beirut' => esc_html__( 'Asia/Beirut', 'ta-mcs' ),
                    'Asia/Bishkek' => esc_html__( 'Asia/Bishkek', 'ta-mcs' ),
                    'Asia/Brunei' => esc_html__( 'Asia/Brunei', 'ta-mcs' ),
                    'Asia/Calcutta' => esc_html__( 'Asia/Calcutta', 'ta-mcs' ),
                    'Asia/Chita' => esc_html__( 'Asia/Chita', 'ta-mcs' ),
                    'Asia/Choibalsan' => esc_html__( 'Asia/Choibalsan', 'ta-mcs' ),
                    'Asia/Chongqing' => esc_html__( 'Asia/Chongqing', 'ta-mcs' ),
                    'Asia/Chungking' => esc_html__( 'Asia/Chungking', 'ta-mcs' ),
                    'Asia/Colombo' => esc_html__( 'Asia/Colombo', 'ta-mcs' ),
                    'Asia/Dacca' => esc_html__( 'Asia/Dacca', 'ta-mcs' ),
                    'Asia/Damascus' => esc_html__( 'Asia/Damascus', 'ta-mcs' ),
                    'Asia/Dhaka' => esc_html__( 'Asia/Dhaka', 'ta-mcs' ),
                    'Asia/Dili' => esc_html__( 'Asia/Dili', 'ta-mcs' ),
                    'Asia/Dubai' => esc_html__( 'Asia/Dubai', 'ta-mcs' ),
                    'Asia/Dushanbe' => esc_html__( 'Asia/Dushanbe', 'ta-mcs' ),
                    'Asia/Famagusta' => esc_html__( 'Asia/Famagusta', 'ta-mcs' ),
                    'Asia/Gaza' => esc_html__( 'Asia/Gaza', 'ta-mcs' ),
                    'Asia/Harbin' => esc_html__( 'Asia/Harbin', 'ta-mcs' ),
                    'Asia/Hebron' => esc_html__( 'Asia/Hebron', 'ta-mcs' ),
                    'Asia/Ho_Chi_Minh' => esc_html__( 'Asia/Ho_Chi_Minh', 'ta-mcs' ),
                    'Asia/Hong_Kong' => esc_html__( 'Asia/Hong_Kong', 'ta-mcs' ),
                    'Asia/Hovd' => esc_html__( 'Asia/Hovd', 'ta-mcs' ),
                    'Asia/Irkutsk' => esc_html__( 'Asia/Irkutsk', 'ta-mcs' ),
                    'Asia/Istanbul' => esc_html__( 'Asia/Istanbul', 'ta-mcs' ),
                    'Asia/Jakarta' => esc_html__( 'Asia/Jakarta', 'ta-mcs' ),
                    'Asia/Jayapura' => esc_html__( 'Asia/Jayapura', 'ta-mcs' ),
                    'Asia/Jerusalem' => esc_html__( 'Asia/Jerusalem', 'ta-mcs' ),
                    'Asia/Kabul' => esc_html__( 'Asia/Kabul', 'ta-mcs' ),
                    'Asia/Kamchatka' => esc_html__( 'Asia/Kamchatka', 'ta-mcs' ),
                    'Asia/Karachi' => esc_html__( 'Asia/Karachi', 'ta-mcs' ),
                    'Asia/Kashgar' => esc_html__( 'Asia/Kashgar', 'ta-mcs' ),
                    'Asia/Kathmandu' => esc_html__( 'Asia/Kathmandu', 'ta-mcs' ),
                    'Asia/Katmandu' => esc_html__( 'Asia/Katmandu', 'ta-mcs' ),
                    'Asia/Khandyga' => esc_html__( 'Asia/Khandyga', 'ta-mcs' ),
                    'Asia/Kolkata' => esc_html__( 'Asia/Kolkata', 'ta-mcs' ),
                    'Asia/Krasnoyarsk' => esc_html__( 'Asia/Krasnoyarsk', 'ta-mcs' ),
                    'Asia/Kuala_Lumpur' => esc_html__( 'Asia/Kuala_Lumpur', 'ta-mcs' ),
                    'Asia/Kuching' => esc_html__( 'Asia/Kuching', 'ta-mcs' ),
                    'Asia/Kuwait' => esc_html__( 'Asia/Kuwait', 'ta-mcs' ),
                    'Asia/Macao' => esc_html__( 'Asia/Macao', 'ta-mcs' ),
                    'Asia/Macau' => esc_html__( 'Asia/Macau', 'ta-mcs' ),
                    'Asia/Magadan' => esc_html__( 'Asia/Magadan', 'ta-mcs' ),
                    'Asia/Makassar' => esc_html__( 'Asia/Makassar', 'ta-mcs' ),
                    'Asia/Manila' => esc_html__( 'Asia/Manila', 'ta-mcs' ),
                    'Asia/Muscat' => esc_html__( 'Asia/Muscat', 'ta-mcs' ),
                    'Asia/Nicosia' => esc_html__( 'Asia/Nicosia', 'ta-mcs' ),
                    'Asia/Novokuznetsk' => esc_html__( 'Asia/Novokuznetsk', 'ta-mcs' ),
                    'Asia/Novosibirsk' => esc_html__( 'Asia/Novosibirsk', 'ta-mcs' ),
                    'Asia/Omsk' => esc_html__( 'Asia/Omsk', 'ta-mcs' ),
                    'Asia/Oral' => esc_html__( 'Asia/Oral', 'ta-mcs' ),
                    'Asia/Phnom_Penh' => esc_html__( 'Asia/Phnom_Penh', 'ta-mcs' ),
                    'Asia/Pontianak' => esc_html__( 'Asia/Pontianak', 'ta-mcs' ),
                    'Asia/Pyongyang' => esc_html__( 'Asia/Pyongyang', 'ta-mcs' ),
                    'Asia/Qatar' => esc_html__( 'Asia/Qatar', 'ta-mcs' ),
                    'Asia/Qyzylorda' => esc_html__( 'Asia/Qyzylorda', 'ta-mcs' ),
                    'Asia/Rangoon' => esc_html__( 'Asia/Rangoon', 'ta-mcs' ),
                    'Asia/Riyadh' => esc_html__( 'Asia/Riyadh', 'ta-mcs' ),
                    'Asia/Saigon' => esc_html__( 'Asia/Saigon', 'ta-mcs' ),
                    'Asia/Sakhalin' => esc_html__( 'Asia/Sakhalin', 'ta-mcs' ),
                    'Asia/Samarkand' => esc_html__( 'Asia/Samarkand', 'ta-mcs' ),
                    'Asia/Seoul' => esc_html__( 'Asia/Seoul', 'ta-mcs' ),
                    'Asia/Shanghai' => esc_html__( 'Asia/Shanghai', 'ta-mcs' ),
                    'Asia/Singapore' => esc_html__( 'Asia/Singapore', 'ta-mcs' ),
                    'Asia/Srednekolymsk' => esc_html__( 'Asia/Srednekolymsk', 'ta-mcs' ),
                    'Asia/Taipei' => esc_html__( 'Asia/Taipei', 'ta-mcs' ),
                    'Asia/Tashkent' => esc_html__( 'Asia/Tashkent', 'ta-mcs' ),
                    'Asia/Tbilisi' => esc_html__( 'Asia/Tbilisi', 'ta-mcs' ),
                    'Asia/Tehran' => esc_html__( 'Asia/Tehran', 'ta-mcs' ),
                    'Asia/Tel_Aviv' => esc_html__( 'Asia/Tel_Aviv', 'ta-mcs' ),
                    'Asia/Thimbu' => esc_html__( 'Asia/Thimbu', 'ta-mcs' ),
                    'Asia/Thimphu' => esc_html__( 'Asia/Thimphu', 'ta-mcs' ),
                    'Asia/Tokyo' => esc_html__( 'Asia/Tokyo', 'ta-mcs' ),
                    'Asia/Tomsk' => esc_html__( 'Asia/Tomsk', 'ta-mcs' ),
                    'Asia/Ujung_Pandang' => esc_html__( 'Asia/Ujung_Pandang', 'ta-mcs' ),
                    'Asia/Ulaanbaatar' => esc_html__( 'Asia/Ulaanbaatar', 'ta-mcs' ),
                    'Asia/Ulan_Bator' => esc_html__( 'Asia/Ulan_Bator', 'ta-mcs' ),
                    'Asia/Urumqi' => esc_html__( 'Asia/Urumqi', 'ta-mcs' ),
                    'Asia/Ust-Nera' => esc_html__( 'Asia/Ust-Nera', 'ta-mcs' ),
                    'Asia/Vientiane' => esc_html__( 'Asia/Vientiane', 'ta-mcs' ),
                    'Asia/Vladivostok' => esc_html__( 'Asia/Vladivostok', 'ta-mcs' ),
                    'Asia/Yakutsk' => esc_html__( 'Asia/Yakutsk', 'ta-mcs' ),
                    'Asia/Yangon' => esc_html__( 'Asia/Yangon', 'ta-mcs' ),
                    'Asia/Yekaterinburg' => esc_html__( 'Asia/Yekaterinburg', 'ta-mcs' ),
                    'Asia/Yerevan' => esc_html__( 'Asia/Yerevan', 'ta-mcs' ),
                    'Atlantic/Azores' => esc_html__( 'Atlantic/Azores', 'ta-mcs' ),
                    'Atlantic/Bermuda' => esc_html__( 'Atlantic/Bermuda', 'ta-mcs' ),
                    'Atlantic/Canary' => esc_html__( 'Atlantic/Canary', 'ta-mcs' ),
                    'Atlantic/Cape_Verde' => esc_html__( 'Atlantic/Cape_Verde', 'ta-mcs' ),
                    'Atlantic/Faeroe' => esc_html__( 'Atlantic/Faeroe', 'ta-mcs' ),
                    'Atlantic/Faroe' => esc_html__( 'Atlantic/Faroe', 'ta-mcs' ),
                    'Atlantic/Jan_Mayen' => esc_html__( 'Atlantic/Jan_Mayen', 'ta-mcs' ),
                    'Atlantic/Madeira' => esc_html__( 'Atlantic/Madeira', 'ta-mcs' ),
                    'Atlantic/Reykjavik' => esc_html__( 'Atlantic/Reykjavik', 'ta-mcs' ),
                    'Atlantic/South_Georgia' => esc_html__( 'Atlantic/South_Georgia', 'ta-mcs' ),
                    'Atlantic/St_Helena' => esc_html__( 'Atlantic/St_Helena', 'ta-mcs' ),
                    'Atlantic/Stanley' => esc_html__( 'Atlantic/Stanley', 'ta-mcs' ),
                    'Australia/ACT' => esc_html__( 'Australia/ACT', 'ta-mcs' ),
                    'Australia/Adelaide' => esc_html__( 'Australia/Adelaide', 'ta-mcs' ),
                    'Australia/Brisbane' => esc_html__( 'Australia/Brisbane', 'ta-mcs' ),
                    'Australia/Broken_Hill' => esc_html__( 'Asia/Broken_Hill', 'ta-mcs' ),
                    'Australia/Canberra' => esc_html__( 'Australia/Canberra', 'ta-mcs' ),
                    'Australia/Currie' => esc_html__( 'Australia/Currie', 'ta-mcs' ),
                    'Australia/Darwin' => esc_html__( 'Australia/Darwin', 'ta-mcs' ),
                    'Australia/Eucla' => esc_html__( 'Australia/Eucla', 'ta-mcs' ),
                    'Australia/Hobart' => esc_html__( 'Australia/Hobart', 'ta-mcs' ),
                    'Australia/LHI' => esc_html__( 'Australia/LHI', 'ta-mcs' ),
                    'Australia/Lindeman' => esc_html__( 'Australia/Lindeman', 'ta-mcs' ),
                    'Australia/Lord_Howe' => esc_html__( 'Australia/Lord_Howe', 'ta-mcs' ),
                    'Australia/Melbourne' => esc_html__( 'Australia/Melbourne', 'ta-mcs' ),
                    'Australia/NSW' => esc_html__( 'Australia/NSW', 'ta-mcs' ),
                    'Australia/North' => esc_html__( 'Australia/North', 'ta-mcs' ),
                    'Australia/Perth' => esc_html__( 'Australia/Perth', 'ta-mcs' ),
                    'Australia/Queensland' => esc_html__( 'Australia/Queensland', 'ta-mcs' ),
                    'Australia/South' => esc_html__( 'Australia/South', 'ta-mcs' ),
                    'Australia/Sydney' => esc_html__( 'Australia/Sydney', 'ta-mcs' ),
                    'Australia/Tasmania' => esc_html__( 'Australia/Tasmania', 'ta-mcs' ),
                    'Australia/Victoria' => esc_html__( 'Australia/Victoria', 'ta-mcs' ),
                    'Australia/West' => esc_html__( 'Australia/West', 'ta-mcs' ),
                    'Australia/Yancowinna' => esc_html__( 'Australia/Yancowinna', 'ta-mcs' ),
                    'Brazil/Acre' => esc_html__( 'Brazil/Acre', 'ta-mcs' ),
                    'Brazil/DeNoronha' => esc_html__( 'Brazil/DeNoronha', 'ta-mcs' ),
                    'Brazil/East' => esc_html__( 'Brazil/East', 'ta-mcs' ),
                    'Brazil/West' => esc_html__( 'Brazil/West', 'ta-mcs' ),
                    'CET' => esc_html__( 'CET', 'ta-mcs' ),
                    'CST6CDT' => esc_html__( 'CST6CDT', 'ta-mcs' ),
                    'Canada/Atlantic' => esc_html__( 'Canada/Atlantic', 'ta-mcs' ),
                    'Canada/Central' => esc_html__( 'Canada/Central', 'ta-mcs' ),
                    'Canada/Eastern' => esc_html__( 'Canada/Eastern', 'ta-mcs' ),
                    'Canada/Mountain' => esc_html__( 'Canada/Mountain', 'ta-mcs' ),
                    'Canada/Newfoundland' => esc_html__( 'Canada/Newfoundland', 'ta-mcs' ),
                    'Canada/Pacific' => esc_html__( 'Canada/Pacific', 'ta-mcs' ),
                    'Canada/Saskatchewan' => esc_html__( 'Canada/Saskatchewan', 'ta-mcs' ),
                    'Canada/Yukon' => esc_html__( 'Canada/Yukon', 'ta-mcs' ),
                    'Chile/Continental' => esc_html__( 'Chile/Continental', 'ta-mcs' ),
                    'Chile/EasterIsland' => esc_html__( 'Chile/EasterIsland', 'ta-mcs' ),
                    'Cuba' => esc_html__( 'Cuba', 'ta-mcs' ),
                    'EET' => esc_html__( 'EET', 'ta-mcs' ),
                    'EST' => esc_html__( 'EST', 'ta-mcs' ),
                    'EST5EDT' => esc_html__( 'EST5EDT', 'ta-mcs' ),
                    'Egypt' => esc_html__( 'Egypt', 'ta-mcs' ),
                    'Eire' => esc_html__( 'Eire', 'ta-mcs' ),
                    'Etc/GMT' => esc_html__( 'Etc/GMT', 'ta-mcs' ),
                    'Etc/GMT+0' => esc_html__( 'Etc/GMT+0', 'ta-mcs' ),
                    'Etc/GMT+1' => esc_html__( 'Etc/GMT+1', 'ta-mcs' ),
                    'Etc/GMT+10' => esc_html__( 'Etc/GMT+10', 'ta-mcs' ),
                    'Etc/GMT+11' => esc_html__( 'Etc/GMT+11', 'ta-mcs' ),
                    'Etc/GMT+12' => esc_html__( 'Etc/GMT+12', 'ta-mcs' ),
                    'Etc/GMT+2' => esc_html__( 'Etc/GMT+2', 'ta-mcs' ),
                    'Etc/GMT+3' => esc_html__( 'Etc/GMT+3', 'ta-mcs' ),
                    'Etc/GMT+4' => esc_html__( 'Etc/GMT+4', 'ta-mcs' ),
                    'Etc/GMT+5' => esc_html__( 'Etc/GMT+5', 'ta-mcs' ),
                    'Etc/GMT+6' => esc_html__( 'Etc/GMT+6', 'ta-mcs' ),
                    'Etc/GMT+7' => esc_html__( 'Etc/GMT+7', 'ta-mcs' ),
                    'Etc/GMT+8' => esc_html__( 'Etc/GMT+8', 'ta-mcs' ),
                    'Etc/GMT+9' => esc_html__( 'Etc/GMT+9', 'ta-mcs' ),
                    'Etc/GMT-0' => esc_html__( 'Etc/GMT-0', 'ta-mcs' ),
                    'Etc/GMT-1' => esc_html__( 'Etc/GMT-1', 'ta-mcs' ),
                    'Etc/GMT-10' => esc_html__( 'Etc/GMT-10', 'ta-mcs' ),
                    'Etc/GMT-11' => esc_html__( 'Etc/GMT-11', 'ta-mcs' ),
                    'Etc/GMT-12' => esc_html__( 'Etc/GMT-12', 'ta-mcs' ),
                    'Etc/GMT-13' => esc_html__( 'Etc/GMT-13', 'ta-mcs' ),
                    'Etc/GMT-14' => esc_html__( 'Etc/GMT-14', 'ta-mcs' ),
                    'Etc/GMT-2' => esc_html__( 'Etc/GMT-2', 'ta-mcs' ),
                    'Etc/GMT-3' => esc_html__( 'Etc/GMT-3', 'ta-mcs' ),
                    'Etc/GMT-4' => esc_html__( 'Etc/GMT-4', 'ta-mcs' ),
                    'Etc/GMT-5' => esc_html__( 'Etc/GMT-5', 'ta-mcs' ),
                    'Etc/GMT-6' => esc_html__( 'Etc/GMT-6', 'ta-mcs' ),
                    'Etc/GMT-7' => esc_html__( 'Etc/GMT-7', 'ta-mcs' ),
                    'Etc/GMT-8' => esc_html__( 'Etc/GMT-8', 'ta-mcs' ),
                    'Etc/GMT-9' => esc_html__( 'Etc/GMT-9', 'ta-mcs' ),
                    'Etc/GMT0' => esc_html__( 'Etc/GMT0', 'ta-mcs' ),
                    'Etc/Greenwich' => esc_html__( 'Etc/Greenwich', 'ta-mcs' ),
                    'Etc/UCT' => esc_html__( 'Etc/UCT', 'ta-mcs' ),
                    'Etc/UTC' => esc_html__( 'Etc/UTC', 'ta-mcs' ),
                    'Etc/Universal' => esc_html__( 'Etc/Universal', 'ta-mcs' ),
                    'Etc/Zulu' => esc_html__( 'Etc/Zulu', 'ta-mcs' ),
                    'Europe/Amsterdam' => esc_html__( 'Europe/Amsterdam', 'ta-mcs' ),
                    'Europe/Andorra' => esc_html__( 'Europe/Andorra', 'ta-mcs' ),
                    'Europe/Astrakhan' => esc_html__( 'Europe/Astrakhan', 'ta-mcs' ),
                    'Europe/Athens' => esc_html__( 'Europe/Athens', 'ta-mcs' ),
                    'Europe/Belfast' => esc_html__( 'Europe/Belfast', 'ta-mcs' ),
                    'Europe/Belgrade' => esc_html__( 'Europe/Belgrade', 'ta-mcs' ),
                    'Europe/Berlin' => esc_html__( 'Europe/Berlin', 'ta-mcs' ),
                    'Europe/Bratislava' => esc_html__( 'Europe/Bratislava', 'ta-mcs' ),
                    'Europe/Brussels' => esc_html__( 'Europe/Brussels', 'ta-mcs' ),
                    'Europe/Bucharest' => esc_html__( 'Europe/Bucharest', 'ta-mcs' ),
                    'Europe/Budapest' => esc_html__( 'Europe/Budapest', 'ta-mcs' ),
                    'Europe/Busingen' => esc_html__( 'Europe/Busingen', 'ta-mcs' ),
                    'Europe/Chisinau' => esc_html__( 'Europe/Chisinau', 'ta-mcs' ),
                    'Europe/Copenhagen' => esc_html__( 'Europe/Copenhagen', 'ta-mcs' ),
                    'Europe/Dublin' => esc_html__( 'Europe/Dublin', 'ta-mcs' ),
                    'Europe/Gibraltar' => esc_html__( 'Europe/Gibraltar', 'ta-mcs' ),
                    'Europe/Guernsey' => esc_html__( 'Europe/Guernsey', 'ta-mcs' ),
                    'Europe/Helsinki' => esc_html__( 'Europe/Helsinki', 'ta-mcs' ),
                    'Europe/Isle_of_Man' => esc_html__( 'Europe/Isle_of_Man', 'ta-mcs' ),
                    'Europe/Istanbul' => esc_html__( 'Europe/Istanbul', 'ta-mcs' ),
                    'Europe/Jersey' => esc_html__( 'Europe/Jersey', 'ta-mcs' ),
                    'Europe/Kaliningrad' => esc_html__( 'Europe/Kaliningrad', 'ta-mcs' ),
                    'Europe/Kiev' => esc_html__( 'Europe/Kiev', 'ta-mcs' ),
                    'Europe/Kirov' => esc_html__( 'Europe/Kirov', 'ta-mcs' ),
                    'Europe/Lisbon' => esc_html__( 'Europe/Lisbon', 'ta-mcs' ),
                    'Europe/Ljubljana' => esc_html__( 'Europe/Ljubljana', 'ta-mcs' ),
                    'Europe/London' => esc_html__( 'Europe/London', 'ta-mcs' ),
                    'Europe/Luxembourg' => esc_html__( 'Europe/Luxembourg', 'ta-mcs' ),
                    'Europe/Madrid' => esc_html__( 'Europe/Madrid', 'ta-mcs' ),
                    'Europe/Malta' => esc_html__( 'Europe/Malta', 'ta-mcs' ),
                    'Europe/Mariehamn' => esc_html__( 'Europe/Mariehamn', 'ta-mcs' ),
                    'Europe/Minsk' => esc_html__( 'Europe/Minsk', 'ta-mcs' ),
                    'Europe/Monaco' => esc_html__( 'Europe/Monaco', 'ta-mcs' ),
                    'Europe/Moscow' => esc_html__( 'Europe/Moscow', 'ta-mcs' ),
                    'Europe/Nicosia' => esc_html__( 'Europe/Nicosia', 'ta-mcs' ),
                    'Europe/Oslo' => esc_html__( 'Europe/Oslo', 'ta-mcs' ),
                    'Europe/Paris' => esc_html__( 'Europe/Paris', 'ta-mcs' ),
                    'Europe/Podgorica' => esc_html__( 'Europe/Podgorica', 'ta-mcs' ),
                    'Europe/Prague' => esc_html__( 'Europe/Prague', 'ta-mcs' ),
                    'Europe/Riga' => esc_html__( 'Europe/Riga', 'ta-mcs' ),
                    'Europe/Rome' => esc_html__( 'Europe/Rome', 'ta-mcs' ),
                    'Europe/Samara' => esc_html__( 'Europe/Samara', 'ta-mcs' ),
                    'Europe/San_Marino' => esc_html__( 'Europe/San_Marino', 'ta-mcs' ),
                    'Europe/Sarajevo' => esc_html__( 'Europe/Sarajevo', 'ta-mcs' ),
                    'Europe/Saratov' => esc_html__( 'Europe/Saratov', 'ta-mcs' ),
                    'Europe/Simferopol' => esc_html__( 'Europe/Simferopol', 'ta-mcs' ),
                    'Europe/Skopje' => esc_html__( 'Europe/Skopje', 'ta-mcs' ),
                    'Europe/Sofia' => esc_html__( 'Europe/Sofia', 'ta-mcs' ),
                    'Europe/Stockholm' => esc_html__( 'Europe/Stockholm', 'ta-mcs' ),
                    'Europe/Tallinn' => esc_html__( 'Europe/Tallinn', 'ta-mcs' ),
                    'Europe/Tirane' => esc_html__( 'Europe/Tirane', 'ta-mcs' ),
                    'Europe/Tiraspol' => esc_html__( 'Europe/Tiraspol', 'ta-mcs' ),
                    'Europe/Ulyanovsk' =>esc_html__( 'Europe/Ulyanovsk', 'ta-mcs' ),
                    'Europe/Uzhgorod' => esc_html__( 'Europe/Uzhgorod', 'ta-mcs' ),
                    'Europe/Vaduz' => esc_html__( 'Europe/Vaduz', 'ta-mcs' ),
                    'Europe/Vatican' => esc_html__( 'Europe/Vatican', 'ta-mcs' ),
                    'Europe/Vienna' => esc_html__( 'Europe/Vienna', 'ta-mcs' ),
                    'Europe/Vilnius' => esc_html__( 'Europe/Vilnius', 'ta-mcs' ),
                    'Europe/Volgograd' => esc_html__( 'Europe/Volgograd', 'ta-mcs' ),
                    'Europe/Warsaw' => esc_html__( 'Europe/Warsaw', 'ta-mcs' ),
                    'Europe/Zagreb' => esc_html__( 'Europe/Zagreb', 'ta-mcs' ),
                    'Europe/Zaporozhye' => esc_html__( 'Europe/Zaporozhye', 'ta-mcs' ),
                    'Europe/Zurich' => esc_html__( 'Europe/Zurich', 'ta-mcs' ),
                    'GB' => esc_html__( 'GB', 'ta-mcs' ),
                    'GB-Eire' => esc_html__( 'GB-Eire', 'ta-mcs' ),
                    'GMT' => esc_html__( 'GMT', 'ta-mcs' ),
                    'GMT+0' => esc_html__( 'GMT+0', 'ta-mcs' ),
                    'GMT-0' => esc_html__( 'GMT-0', 'ta-mcs' ),
                    'GMT0' => esc_html__( 'GMT0', 'ta-mcs' ),
                    'Greenwich' => esc_html__( 'Greenwich', 'ta-mcs' ),
                    'HST' => esc_html__( 'HST', 'ta-mcs' ),
                    'Hongkong' => esc_html__( 'Hongkong', 'ta-mcs' ),
                    'Iceland' => esc_html__( 'Iceland', 'ta-mcs' ),
                    'Indian/Antananarivo' => esc_html__( 'Indian/Antananarivo', 'ta-mcs' ),
                    'Indian/Chagos' => esc_html__( 'Indian/Chagos', 'ta-mcs' ),
                    'Indian/Christmas' => esc_html__( 'Indian/Christmas', 'ta-mcs' ),
                    'Indian/Cocos' => esc_html__( 'Indian/Cocos', 'ta-mcs' ),
                    'Indian/Comoro' => esc_html__( 'Indian/Comoro', 'ta-mcs' ),
                    'Indian/Kerguelen' => esc_html__( 'Indian/Kerguelen', 'ta-mcs' ),
                    'Indian/Mahe' => esc_html__( 'Indian/Mahe', 'ta-mcs' ),
                    'Indian/Maldives' => esc_html__( 'Indian/Maldives', 'ta-mcs' ),
                    'Indian/Mauritius' => esc_html__( 'Indian/Mauritius', 'ta-mcs' ),
                    'Indian/Mayotte' => esc_html__( 'Indian/Mayotte', 'ta-mcs' ),
                    'Indian/Reunion' => esc_html__( 'Indian/Reunion', 'ta-mcs' ),
                    'Iran' => esc_html__( 'Iran', 'ta-mcs' ),
                    'Israel' => esc_html__( 'Israel', 'ta-mcs' ),
                    'Jamaica' => esc_html__( 'Jamaica', 'ta-mcs' ),
                    'Japan' => esc_html__( 'Japan', 'ta-mcs' ),
                    'Kwajalein' => esc_html__( 'Kwajalein', 'ta-mcs' ),
                    'Libya' => esc_html__( 'Libya', 'ta-mcs' ),
                    'MET' => esc_html__( 'MET', 'ta-mcs' ),
                    'MST' => esc_html__( 'MST', 'ta-mcs' ),
                    'MST7MDT' => esc_html__( 'MST7MDT', 'ta-mcs' ),
                    'Mexico/BajaNorte' => esc_html__( 'Mexico/BajaNorte', 'ta-mcs' ),
                    'Mexico/BajaSur' => esc_html__( 'Mexico/BajaSur', 'ta-mcs' ),
                    'Mexico/General' => esc_html__( 'Mexico/General', 'ta-mcs' ),
                    'NZ' => esc_html__( 'NZ', 'ta-mcs' ),
                    'NZ-CHAT' => esc_html__( 'NZ-CHAT', 'ta-mcs' ),
                    'Navajo' => esc_html__( 'Navajo', 'ta-mcs' ),
                    'PRC' => esc_html__( 'PRC', 'ta-mcs' ),
                    'PST8PDT' => esc_html__( 'PST8PDT', 'ta-mcs' ),
                    'Pacific/Apia' => esc_html__( 'Pacific/Apia', 'ta-mcs' ),
                    'Pacific/Auckland' => esc_html__( 'Pacific/Auckland', 'ta-mcs' ),
                    'Pacific/Bougainville' => esc_html__( 'Pacific/Bougainville', 'ta-mcs' ),
                    'Pacific/Chatham' => esc_html__( 'Pacific/Chatham', 'ta-mcs' ),
                    'Pacific/Chuuk' => esc_html__( 'Pacific/Chuuk', 'ta-mcs' ),
                    'Pacific/Easter' => esc_html__( 'Pacific/Easter', 'ta-mcs' ),
                    'Pacific/Efate' => esc_html__( 'Pacific/Efate', 'ta-mcs' ),
                    'Pacific/Enderbury' => esc_html__( 'Pacific/Enderbury', 'ta-mcs' ),
                    'Pacific/Fakaofo' => esc_html__( 'Pacific/Fakaofo', 'ta-mcs' ),
                    'Pacific/Fiji' => esc_html__( 'Pacific/Fiji', 'ta-mcs' ),
                    'Pacific/Funafuti' => esc_html__( 'Pacific/Funafuti', 'ta-mcs' ),
                    'Pacific/Galapagos' => esc_html__( 'Pacific/Galapagos', 'ta-mcs' ),
                    'Pacific/Gambier' => esc_html__( 'Pacific/Gambier', 'ta-mcs' ),
                    'Pacific/Guadalcanal' => esc_html__( 'Pacific/Guadalcanal', 'ta-mcs' ),
                    'Pacific/Guam' => esc_html__( 'Pacific/Guam', 'ta-mcs' ),
                    'Pacific/Honolulu' => esc_html__( 'Pacific/Honolulu', 'ta-mcs' ),
                    'Pacific/Johnston' => esc_html__( 'Pacific/Johnston', 'ta-mcs' ),
                    'Pacific/Kiritimati' => esc_html__( 'Pacific/Kiritimati', 'ta-mcs' ),
                    'Pacific/Kosrae' => esc_html__( 'Pacific/Kosrae', 'ta-mcs' ),
                    'Pacific/Kwajalein' => esc_html__( 'Pacific/Kwajalein', 'ta-mcs' ),
                    'Pacific/Majuro' => esc_html__( 'Pacific/Majuro', 'ta-mcs' ),
                    'Pacific/Marquesas' => esc_html__( 'Pacific/Marquesas', 'ta-mcs' ),
                    'Pacific/Midway' => esc_html__( 'Pacific/Midway', 'ta-mcs' ),
                    'Pacific/Nauru' => esc_html__( 'Pacific/Nauru', 'ta-mcs' ),
                    'Pacific/Niue' => esc_html__( 'Pacific/Niue', 'ta-mcs' ),
                    'Pacific/Norfolk' => esc_html__( 'Pacific/Norfolk', 'ta-mcs' ),
                    'Pacific/Noumea' => esc_html__( 'Pacific/Noumea', 'ta-mcs' ),
                    'Pacific/Pago_Pago' => esc_html__( 'Pacific/Pago_Pago', 'ta-mcs' ),
                    'Pacific/Palau' => esc_html__( 'Pacific/Palau', 'ta-mcs' ),
                    'Pacific/Pitcairn' => esc_html__( 'Pacific/Pitcairn', 'ta-mcs' ),
                    'Pacific/Pohnpei' => esc_html__( 'Pacific/Pohnpei', 'ta-mcs' ),
                    'Pacific/Ponape' => esc_html__( 'Pacific/Ponape', 'ta-mcs' ),
                    'Pacific/Port_Moresby' => esc_html__( 'Pacific/Port_Moresby', 'ta-mcs' ),
                    'Pacific/Rarotonga' => esc_html__( 'Pacific/Rarotonga', 'ta-mcs' ),
                    'Pacific/Saipan' => esc_html__( 'Pacific/Saipan', 'ta-mcs' ),
                    'Pacific/Samoa' => esc_html__( 'Pacific/Samoa', 'ta-mcs' ),
                    'Pacific/Tahiti' => esc_html__( 'Pacific/Tahiti', 'ta-mcs' ),
                    'Pacific/Tarawa' => esc_html__( 'Pacific/Tarawa', 'ta-mcs' ),
                    'Pacific/Tongatapu' => esc_html__( 'Pacific/Tongatapu', 'ta-mcs' ),
                    'Pacific/Truk' => esc_html__( 'Pacific/Truk', 'ta-mcs' ),
                    'Pacific/Wake' => esc_html__( 'Pacific/Wake', 'ta-mcs' ),
                    'Pacific/Wallis' => esc_html__( 'Pacific/Wallis', 'ta-mcs' ),
                    'Pacific/Yap' => esc_html__( 'Pacific/Yap', 'ta-mcs' ),
                    'Poland' => esc_html__( 'Poland', 'ta-mcs' ),
                    'Portugal' => esc_html__( 'Portugal', 'ta-mcs' ),
                    'ROC' => esc_html__( 'ROC', 'ta-mcs' ),
                    'ROK' => esc_html__( 'ROK', 'ta-mcs' ),
                    'Singapore' => esc_html__( 'Singapore', 'ta-mcs' ),
                    'Turkey' => esc_html__( 'Turkey', 'ta-mcs' ),
                    'UCT' => esc_html__( 'UCT', 'ta-mcs' ),
                    'US/Alaska' => esc_html__( 'US/Alaska', 'ta-mcs' ),
                    'US/Aleutian' => esc_html__( 'US/Aleutian', 'ta-mcs' ),
                    'US/Arizona' => esc_html__( 'US/Arizona', 'ta-mcs' ),
                    'US/Central' => esc_html__( 'US/Central', 'ta-mcs' ),
                    'US/East-Indiana' => esc_html__( 'US/East-Indiana', 'ta-mcs' ),
                    'US/Eastern' => esc_html__( 'US/Eastern', 'ta-mcs' ),
                    'US/Hawaii' => esc_html__( 'US/Hawaii', 'ta-mcs' ),
                    'US/Indiana-Starke' => esc_html__( 'US/Indiana-Starke', 'ta-mcs' ),
                    'US/Michigan' => esc_html__( 'US/Michigan', 'ta-mcs' ),
                    'US/Mountain' => esc_html__( 'US/Mountain', 'ta-mcs' ),
                    'US/Pacific' => esc_html__( 'US/Pacific', 'ta-mcs' ),
                    'US/Pacific-New' => esc_html__( 'US/Pacific-New', 'ta-mcs' ),
                    'US/Samoa' => esc_html__( 'US/Samoa', 'ta-mcs' ),
                    'UTC' => esc_html__( 'UTC', 'ta-mcs' ),
                    'Universal' => esc_html__( 'Universal', 'ta-mcs' ),
                    'W-SU' => esc_html__( 'W-SU', 'ta-mcs' ),
                    'WET' => esc_html__( 'WET', 'ta-mcs' ),
                )
            ]
        );


        // start sunday popover
        $this->add_control(
			'popover-sunday',
			[
				'label' => esc_html__( 'Sunday', 'ta-chat' ),
				'type' => \Elementor\Controls_Manager::POPOVER_TOGGLE,
			]
		);


        $this->start_popover();
        $this->add_control(
            'sunday__start', [
                'label' => esc_html__( 'Start time', 'ta-mcs' ),
                'type'  => Controls_Manager::TEXT,
                'label_block' => false,
                'default' => '00:00',
                'condition' => [
                    'popover-sunday' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'sunday__end', [
                'label' => esc_html__( 'End time', 'ta-mcs' ),
                'type'  => Controls_Manager::TEXT,
                'label_block' => false,
                'default' => '23:59',
                'condition' => [
                    'popover-sunday' => 'yes',
                ],
            ]
        );

		$this->end_popover();
        // end sunday popover

        // start monday popover
        $this->add_control(
			'popover-monday',
			[
				'label' => esc_html__( 'Monday', 'ta-chat' ),
				'type' => \Elementor\Controls_Manager::POPOVER_TOGGLE,
			]
		);

        $this->start_popover();
        $this->add_control(
            'monday__start', [
                'label' => esc_html__( 'Start time', 'ta-mcs' ),
                'type'  => Controls_Manager::TEXT,
                'label_block' => false,
                'default' => '00:00',
                'condition' => [
                    'popover-monday' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'monday__end', [
                'label' => esc_html__( 'End time', 'ta-mcs' ),
                'type'  => Controls_Manager::TEXT,
                'label_block' => false,
                'default' => '23:59',
                'condition' => [
                    'popover-monday' => 'yes',
                ],
            ]
        );

		$this->end_popover();
        // end monday popover

        // start tuesday popover
        $this->add_control(
			'popover-tuesday',
			[
				'label' => esc_html__( 'Tuesday', 'ta-chat' ),
				'type' => \Elementor\Controls_Manager::POPOVER_TOGGLE,
			]
		);

        $this->start_popover();
        $this->add_control(
            'tuesday__start', [
                'label' => esc_html__( 'Start time', 'ta-mcs' ),
                'type'  => Controls_Manager::TEXT,
                'label_block' => false,
                'default' => '00:00',
                'condition' => [
                    'popover-tuesday' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'tuesday__end', [
                'label' => esc_html__( 'End time', 'ta-mcs' ),
                'type'  => Controls_Manager::TEXT,
                'label_block' => false,
                'default' => '23:59',
                'condition' => [
                    'popover-tuesday' => 'yes',
                ],
            ]
        );

		$this->end_popover();
        // end tuesday popover

        // start wednesday popover
        $this->add_control(
			'popover-wednesday',
			[
				'label' => esc_html__( 'Wednesday', 'ta-chat' ),
				'type' => \Elementor\Controls_Manager::POPOVER_TOGGLE,
			]
		);

        $this->start_popover();
        $this->add_control(
            'wednesday__start', [
                'label' => esc_html__( 'Start time', 'ta-mcs' ),
                'type'  => Controls_Manager::TEXT,
                'label_block' => false,
                'default' => '00:00',
                'condition' => [
                    'popover-wednesday' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'wednesday__end', [
                'label' => esc_html__( 'End time', 'ta-mcs' ),
                'type'  => Controls_Manager::TEXT,
                'label_block' => false,
                'default' => '23:59',
                'condition' => [
                    'popover-wednesday' => 'yes',
                ],
            ]
        );

		$this->end_popover();
        // end wednesday popover

        // start sunday popover
        $this->add_control(
			'popover-thursday',
			[
				'label' => esc_html__( 'Thursday', 'ta-chat' ),
				'type' => \Elementor\Controls_Manager::POPOVER_TOGGLE,
			]
		);

        $this->start_popover();
        $this->add_control(
            'thursday__start', [
                'label' => esc_html__( 'Start time', 'ta-mcs' ),
                'type'  => Controls_Manager::TEXT,
                'label_block' => false,
                'default' => '00:00',
                'condition' => [
                    'popover-thursday' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'thursday__end', [
                'label' => esc_html__( 'End time', 'ta-mcs' ),
                'type'  => Controls_Manager::TEXT,
                'label_block' => false,
                'default' => '23:59',
                'condition' => [
                    'popover-thursday' => 'yes',
                ],
            ]
        );

		$this->end_popover();
        // end thursday popover

        // start sunday popover
        $this->add_control(
			'popover-friday',
			[
				'label' => esc_html__( 'Friday', 'ta-chat' ),
				'type' => \Elementor\Controls_Manager::POPOVER_TOGGLE,
			]
		);

        $this->start_popover();
        $this->add_control(
            'friday__start', [
                'label' => esc_html__( 'Start time', 'ta-mcs' ),
                'type'  => Controls_Manager::TEXT,
                'label_block' => false,
                'default' => '00:00',
                'condition' => [
                    'popover-friday' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'friday__end', [
                'label' => esc_html__( 'End time', 'ta-mcs' ),
                'type'  => Controls_Manager::TEXT,
                'label_block' => false,
                'default' => '23:59',
                'condition' => [
                    'popover-friday' => 'yes',
                ],
            ]
        );

		$this->end_popover();
        // end friday popover

        $this->add_control(
			'popover-saturday',
			[
				'label' => esc_html__( 'Saturday', 'ta-chat' ),
				'type' => \Elementor\Controls_Manager::POPOVER_TOGGLE,
			]
		);

		$this->start_popover();
        $this->add_control(
            'saturday__start', [
                'label' => esc_html__( 'Start time', 'ta-mcs' ),
                'type'  => Controls_Manager::TEXT,
                'label_block' => false,
                'default' => '00:00',
                'condition' => [
                    'popover-saturday' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'saturday__end', [
                'label' => esc_html__( 'End time', 'ta-mcs' ),
                'type'  => Controls_Manager::TEXT,
                'label_block' => false,
                'default' => '23:59',
                'condition' => [
                    'popover-saturday' => 'yes',
                ],
            ]
        );
		$this->end_popover();

        $this->end_controls_section(); // End section top content
        
        $this->start_controls_section(
			'mcs__appearance',
			[
				'label' => esc_html__( 'Appearance settings', 'ta-mcs' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);

        $this->add_control(
            'visibility', [
                'label' => esc_html__( 'Visibility on', 'ta-mcs' ),
                'type'  => Controls_Manager::SELECT2,
                'label_block' => false,
                'default' => 'mSupport-show-everywhere',
                'options' => array(
                    'mSupport-show-everywhere'  => esc_html__( 'Everywhere', 'ta-mcs' ),
                    'mSupport-desktop-only'  => esc_html__( 'Desktops only', 'ta-mcs' ),
                    'mSupport-tablet-only'  => esc_html__( 'Tablets only', 'ta-mcs' ),
                    'mSupport-mobile-tablet-only'  => esc_html__( 'Mobile and tablets', 'ta-mcs' ),
                    'mSupport-mobile-only'  => esc_html__( 'Mobile only', 'ta-mcs' ),
                )

            ]
        );

        $this-> add_control(
            'button__sizes', [
                'label' => esc_html__( 'Size', 'ta-mcs' ),
                'type'  => Controls_Manager::SELECT,
                'label_block' => false,
                'default' => 'mSupport-btn-md',
                'options' => array(
                    'mSupport-btn-sm' => esc_html__( 'Small', 'ta-mcs' ),
                    'mSupport-btn-md' => esc_html__( 'Medium', 'ta-mcs' ),
                    'mSupport-btn-lg' => esc_html__( 'Large', 'ta-mcs' ),
                )
            ]
        );

        $this->add_control(
			'bg__color',
			[
				'label' => esc_html__( 'Backgound color', 'ta-mcs' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'default' => '#0084ff',
                'selectors' => [
					'{{WRAPPER}} [class*="mSupport-button-"].mSupport-btn-bg' => 'background-color: {{VALUE}}'
				],
			]
        );

        $this->add_control(
			'bg__color__hover',
			[
				'label' => esc_html__( 'Hover backgound color', 'ta-mcs' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'default' => '#0066ff',
                'selectors' => [
					'{{WRAPPER}} [class*="mSupport-button-"].mSupport-btn-bg:hover' => 'background-color: {{VALUE}}'
				],
			]
        );

        $this->add_control(
			'text__color',
			[
				'label' => esc_html__( 'Text color', 'ta-mcs' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'default' => '#ffffff',
                'selectors' => [
					'{{WRAPPER}} [class*="mSupport-button-"].mSupport-btn-bg' => 'color: {{VALUE}}',
				],
			]
        );

        $this->add_control(
			'text__color__hover',
			[
				'label' => esc_html__( 'Hover text color', 'ta-mcs' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'default' => '#ffffff',
                'selectors' => [
					'{{WRAPPER}} [class*="mSupport-button-"].mSupport-btn-bg:hover' => 'color: {{VALUE}}',
				],
			]
        );


        $this->add_group_control(
			\Elementor\Group_Control_Border::get_type(),
			[
				'name' => 'border',
				'label' => esc_html__( 'Border', 'ta-mcs' ),
				'selector' => '{{WRAPPER}} .mSupportButtons, {{WRAPPER}} .mSupport-button-2',
                'fields_options' => [
                    'border' => [
                        'label' => esc_html__( 'Border', 'ta-mcs' ),
                        'default' => 'solid',
                    ],
                    'width' => [
                        'default' => [
                            'top' => '1',
                            'right' => '1',
                            'bottom' => '1',
                            'left' => '1',
                            'isLinked' => false,
                        ],
                    ],
                    'color' => [
                        'default' => '#0084ff',
                    ],
                ],
			]
		);

        $this->add_group_control(
			\Elementor\Group_Control_Border::get_type(),
			[
				'name' => 'border__hover',
				'label' => esc_html__( 'Hover border', 'ta-mcs' ),
                'default' => '#0066ff',
				'selector' => '{{WRAPPER}} .mSupportButtons:hover, {{WRAPPER}} .mSupport-button-2:hover',
                'fields_options' => [
                    'border' => [
                        'label' => esc_html__( 'Hover border', 'ta-mcs' ),
                        'default' => 'solid',
                    ],
                    'width' => [
                        'default' => [
                            'top' => '1',
                            'right' => '1',
                            'bottom' => '1',
                            'left' => '1',
                            'isLinked' => false,
                        ],
                    ],
                    'color' => [
                        'default' => '#0066ff',
                    ],
                ],
			]
		);

        $this->add_control(
			'button__icon',
			[
				'label' => esc_html__( 'Change icon', 'ta-mcs' ),
				'type' => \Elementor\Controls_Manager::ICONS,
				'default' => [
					'value' => 'fab fa-facebook-messenger',
				],
                'condition' => [
                    'style' => '2',
                ],
				'recommended' => [
					'fa-solid' => [
						'envelope',
						'envelope-open',
						'facebook-messenger',
					],
					'fa-regular' => [
						'envelope',
						'envelope-open',
					],
                    
				],
			]
		);

        $this->add_control(
			'icon__color',
			[
				'label' => esc_html__( 'Icon color', 'ta-mcs' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'default' => '#0084ff',
                'selectors' => [
                    '{{WRAPPER}} [class*="mSupport-button-"].mSupport-btn-bg i' => 'color: {{VALUE}}',
				],
                'condition' => [
                    'style' => '2',
                ],
			]
        );

        $this->add_control(
			'icon__color__hover',
			[
				'label' => esc_html__( 'Icon hover color', 'ta-mcs' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'default' => '#0066ff',
                'selectors' => [
                    '{{WRAPPER}} [class*="mSupport-button-"].mSupport-btn-bg:hover i' => 'color: {{VALUE}}',
				],
                'condition' => [
                    'style' => '2',
                ],
			]
        );

        $this->add_control(
            'show__icon__bg__color', [
                'label' => esc_html__( 'Want bg in icon?', 'ta-mcs' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Yes', 'ta-mcs' ),
				'label_off' => esc_html__( 'No', 'ta-mcs' ),
				'return_value' => 'cmSupporttd-button-3',
                'condition' => [
                    'style' => '2',
                ],
            ]
        );

        $this->add_control(
			'icon__bg__color',
			[
				'label' => esc_html__( 'Icon bg color', 'ta-mcs' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'default' => '#fff',
                'selectors' => [
                    '{{WRAPPER}} [class*="mSupport-button-"].mSupport-button-3.mSupport-btn-bg i' => 'background-color: {{VALUE}}',
				],
                'condition' => [
                    'style' => '2',
                    'show__icon__bg__color' => 'mSupport-button-3',
                ],
			]
        );

        $this->add_control(
			'icon__bg__color__hover',
			[
				'label' => esc_html__( 'Icon hover bg color', 'ta-mcs' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'default' => '#ffffff',
                'selectors' => [
                    '{{WRAPPER}} [class*="mSupport-button-"].mSupport-button-3.mSupport-btn-bg:hover i' => 'background-color: {{VALUE}}',
				],
                'condition' => [
                    'style' => '2',
                    'show__icon__bg__color' => 'mSupport-button-3',
                ],
			]
        );

        $this->add_control(
            'rounded', [
                'label' => esc_html__( 'Rounded?', 'ta-mcs' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Yes', 'ta-mcs' ),
				'label_off' => esc_html__( 'No', 'ta-mcs' ),
				'return_value' => 'mSupport-btn-rounded',
            ]
        );

        $this->add_control(
			'text_align',
			[
				'label' => esc_html__( 'Alignment', 'ta-mcs' ),
				'type' => \Elementor\Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'ta-mcs' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'ta-mcs' ),
						'icon' => 'eicon-text-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'ta-mcs' ),
						'icon' => 'eicon-text-align-right',
					],
				],
				'default' => 'left',
				'toggle' => true,
				'selectors' => [
					'{{WRAPPER}} .button-wrapper' => 'text-align: {{VALUE}};',
				],
			]
		);

        $this->end_controls_section(); // End section top content
	}

    protected function render() {
        $settings = $this->get_settings_for_display();
        // button settings
        $style = $settings['style'];
        $fbid =  $settings['fbid'];
        $timezone =  $settings['timezone'];
        $visibility = $settings['visibility'];
        $icon = $settings['button__icon']['value'];
        $rounded = $settings['rounded'];
        $icon__bg = $settings['show__icon__bg__color'];
        $sizes = $settings['button__sizes'];
        $photo = $settings['agent__photo']['url'];
        $name = $settings['agent__name'];
        $designation = $settings['agent__designation'];
        $labelText = $settings['custom__button__label'];
        $onlineText = $settings['online__text'];
        $offlineText = $settings['offline__text'];
        // availablity
        
        $sunday = ($settings['sunday__start'] ? $settings['sunday__start']: "0:00")."-".($settings['sunday__end'] ? $settings['sunday__end']:"23:59");
        $monday = ($settings['monday__start'] ? $settings['monday__start']: "0:00")."-".($settings['monday__end'] ? $settings['monday__end']:"23:59");
        $tuesday = ($settings['tuesday__start'] ? $settings['tuesday__start']: "0:00")."-".($settings['tuesday__end'] ? $settings['tuesday__end']:"23:59");
        $wednesday = ($settings['wednesday__start'] ? $settings['wednesday__start']: "0:00")."-".($settings['wednesday__end'] ? $settings['wednesday__end']:"23:59");
        $thursday = ($settings['thursday__start'] ? $settings['thursday__start']: "0:00")."-".($settings['thursday__end'] ? $settings['thursday__end']:"23:59");
        $friday = ($settings['friday__start'] ? $settings['friday__start']: "0:00")."-".($settings['friday__end'] ? $settings['friday__end']:"23:59");
        $saturday = ($settings['saturday__start'] ? $settings['saturday__start']: "0:00")."-".($settings['saturday__end'] ? $settings['saturday__end']:"23:59");
        $mcsIcon = $icon ? $icon : "fas fa-phone-alt";
        
		?>
        <?php if($style == '1'):?>
            <div class="button-wrapper">
            <button <?php if( $timezone) { ?> data-timezone="<?php esc_attr($timezone); ?>" <?php } ?> class="mSupportButtons mSupport-button-4 mSupport-btn-bg <?php echo esc_attr($visibility); ?> <?php echo esc_attr($rounded); ?> avatar-active <?php echo esc_attr($sizes); ?>" data-btnavailablety='{ "sunday":"<?php echo esc_attr( $sunday);?>", "monday":"<?php echo esc_attr( $monday);?>", "tuesday":"<?php echo esc_attr( $tuesday);?>", "wednesday":"<?php echo esc_attr( $wednesday);?>", "thursday":"<?php echo esc_attr( $thursday);?>", "friday":"<?php echo esc_attr( $friday);?>", "saturday":"<?php echo esc_attr( $saturday);?>" }'>
            <?php if ($photo) { ?>
            <img src="<?php echo esc_attr( $photo ); ?>"/>
            <?php } ?>
            <div class="info-wrapper">
            <?php if( $name || $designation ) { ?>
                <p class="info"><?php if( $name ) { ?><?php echo esc_html( $name ); ?><?php } ?> <?php if( $designation ) { ?>/ <?php echo esc_html( $designation ); ?><?php } ?></p>
            <?php } ?>
            <?php if( $labelText ) { ?>
                <p class="title"><?php echo esc_html( $labelText ); ?></p>
            <?php } ?>
            <?php if( $onlineText ) { ?>
                <p class="online"><?php echo esc_html( $onlineText ); ?></p>
            <?php } ?>
            <?php if( $offlineText ) { ?>
                <p class="offline"><?php echo esc_html( $offlineText ); ?></p>
                <?php } ?>
            </div>
            <a href="https://www.m.me/<?php echo esc_attr($fbid); ?>" target="_blank"></a>
            </button>
            </div>
        <?php else : ?>
            <div class="button-wrapper">
                <a href="https://www.m.me/<?php echo $fbid; ?>" class="mSupport-button-2 <?php echo esc_attr($icon__bg); ?> mSupport-btn-bg <?php echo esc_attr($visibility); ?> <?php echo esc_attr($rounded); ?> <?php echo esc_attr($sizes); ?>">
                <i class="<?php echo $mcsIcon;?>"></i> <?php if( $labelText ) { ?><span><?php echo esc_html( $labelText ); ?></span><?php } ?>
                </a>
            </div>
        <?php endif;?>
<?php }

}